Environment class

SDK environment constraints from pubspec.yaml.

Provides typed access to Dart SDK and Flutter SDK version constraints.

Annotations

Constructors

Environment({required String sdk, String? flutter})
const

Properties

flutter String?
Flutter SDK version constraint (e.g. '>=3.22.0').
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdk String
Dart SDK version constraint (e.g. '^3.10.0').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited