IconData class

A helper class that stores the data for an SVG icon.

Constructors

IconData(List<Map<String, dynamic>> content)
Creates icon data from a list of SVG element maps.
const

Properties

content List<Map<String, dynamic>>
A list of XML elements that form an SVG.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited