VersioningConfig class

Configuration for documentation versioning.

Annotations

Constructors

VersioningConfig({bool enabled = false, List<String> versions = const [], String defaultVersion = '', String versionDir = 'versions'})
const
VersioningConfig.fromJson(Map<String, dynamic> json)
factory

Properties

defaultVersion String
Default version to show.
final
enabled bool
Whether versioning is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionDir String
Directory containing versioned docs.
final
versions List<String>
List of available versions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited