DocLink class
A navigable documentation page link.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Display name shown in the sidebar.
finalinherited
- order → int
-
Sort order (from filename prefix or frontmatter sidebar_position).
finalinherited
- path → String
-
URL path for this page (e.g., '/docs/getting-started').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited