Pubspec class
Represents the user's project pubspec.yaml fields.
Provides access to metadata like package name, version, description, and URLs that can be used in the site configuration.
- Annotations
Constructors
Properties
- description → String?
-
Package description.
final
- documentation → String?
-
Documentation URL.
final
- environment → Environment
-
SDK environment constraints.
final
-
funding
→ List<
String> ? -
Funding URLs where users can sponsor development.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- homepage → String?
-
Homepage URL.
final
- issueTracker → String?
-
Issue tracker URL.
final
- name → String
-
Package name (required in pubspec.yaml).
final
- publishTo → String?
-
Publish target (or 'none' to prevent publishing).
final
- repository → Repository?
-
Source code repository with auto-detected provider info.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topics
→ List<
String> ? -
Topic tags for package categorization.
final
- version → String?
-
Package version (e.g. '1.0.0').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited